pub struct CompletionItem {
pub label: String,
pub kind: Option<u32>,
pub detail: Option<String>,
pub documentation: Option<Value>,
pub insert_text: Option<String>,
}Expand description
A completion item represents a text snippet that is proposed to complete text that is being typed.
Fields
label: StringThe label of this completion item (shown in the UI).
kind: Option<u32>The kind of this completion item (maps to CompletionItemKind).
detail: Option<String>A human-readable string with additional information.
documentation: Option<Value>Documentation for this completion item (can be string or MarkupContent).
insert_text: Option<String>A string that should be inserted into a document when selecting this item.