Module executor

Module executor 

Sandboxed tool executor that wraps tool execution in a WASM sandbox.

Provides SandboxedExecutor which can execute WASM modules with configurable resource limits and capability-based permissions, as well as sandbox existing tool invocations for additional isolation.

Structs

ConfigSnapshot
Snapshot of configuration at time of execution.
SandboxExecution
The complete result of a sandboxed execution, including timing and config info.
SandboxedExecutor
Executes WASM modules within a sandboxed environment.